==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Wifi activé</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Wifi désactivé</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Verrouillage majuscules activé</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Verrouillage majuscules désactivé</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Pavé numérique activé</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Pavé numérique désactivé</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Pavé tactile activé</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Pavé tactile désactivé</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Basculer le pavé tactile</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Basculer les touches Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Mode avion activé</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Mode avion désactivé</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Mode d&apos;énergie équilibré</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Mode d&apos;économie d&apos;énergie</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Mode haute performance</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Effets de fenêtres activés</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Effets de fenêtres désactivés</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Impossible d&apos;activer les effets de fenêtres</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>Microphone désactivé</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>Microphone activé</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Wifi activé</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Wifi désactivé</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Verrouillage majuscules activé</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Verrouillage majuscules désactivé</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Pavé numérique activé</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Pavé numérique désactivé</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Pavé tactile activé</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Pavé tactile désactivé</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Basculer le pavé tactile</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Basculer les touches Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Mode avion activé</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Mode avion désactivé</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Mode d&apos;énergie équilibré</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Mode d&apos;économie d&apos;énergie</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Mode haute performance</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Effets de fenêtres activés</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Effets de fenêtres désactivés</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Impossible d&apos;activer les effets de fenêtres</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>Microphone désactivé</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>Microphone activé</translation>
    </message>
    <message>
        <source>Camera on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Camera off</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
